"use strict";

function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }

  if (!value || !value.then) {
    value = Promise.resolve(value);
  }

  return then ? value.then(then) : value;
}

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }

    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Dialog = void 0;

var react_1 = __importDefault(require("react"));

var with_default_props_1 = require("../../utils/with-default-props");

var classnames_1 = __importDefault(require("classnames"));

var mask_1 = __importDefault(require("../mask"));

var dialog_action_button_1 = require("./dialog-action-button");

var image_1 = __importDefault(require("../image"));

var space_1 = __importDefault(require("../space"));

var classPrefix = "am-dialog";
var defaultProps = {
  actions: [],
  closeOnAction: false,
  closeOnMaskClick: false
};

exports.Dialog = function (p) {
  var props = with_default_props_1.mergeProps(defaultProps, p);
  return react_1["default"].createElement(mask_1["default"], {
    visible: props.visible,
    destroyOnClose: true,
    getContainer: props.getContainer,
    afterClose: props.afterClose,
    onMaskClick: props.closeOnMaskClick ? props.onClose : undefined,
    style: props.maskStyle,
    className: classnames_1["default"](classPrefix + "-mask", props.maskClassName)
  }, react_1["default"].createElement("div", {
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    className: classPrefix + "-wrap"
  }, !!props.image && react_1["default"].createElement(image_1["default"], {
    src: props.image,
    alt: 'dialog header image',
    width: '100%'
  }), react_1["default"].createElement("div", {
    style: props.bodyStyle,
    className: classnames_1["default"](classPrefix + "-body", props.bodyClassName)
  }, react_1["default"].createElement(space_1["default"], {
    direction: 'vertical',
    block: true
  }, !!props.header && react_1["default"].createElement("div", {
    className: classPrefix + "-body-header-wrapper"
  }, react_1["default"].createElement("div", {
    className: classPrefix + "-body-header"
  }, props.header)), !!props.title && react_1["default"].createElement("div", {
    className: classPrefix + "-body-title"
  }, props.title), !!props.content && react_1["default"].createElement("div", {
    className: classPrefix + "-body-message-wrapper"
  }, react_1["default"].createElement("div", {
    className: classPrefix + "-body-message"
  }, props.content)))), react_1["default"].createElement("div", {
    className: classPrefix + "-footer"
  }, props.actions.map(function (row, index) {
    var actions = Array.isArray(row) ? row : [row];
    return react_1["default"].createElement("div", {
      className: classPrefix + "-action-row",
      key: index
    }, actions.map(function (action, index) {
      return react_1["default"].createElement(dialog_action_button_1.DialogActionButton, {
        key: action.key,
        action: action,
        onAction: _async(function () {
          return _await(props.onAction == null ? void 0 : props.onAction(action, index), function () {
            if (props.closeOnAction) {
              props.onClose == null ? void 0 : props.onClose();
            }
          });
        })
      });
    }));
  }))));
};