import React from 'react';
import { mergeProps } from '../../utils/with-default-props';
import classNames from 'classnames';
import Mask from '../mask';
import { DialogActionButton } from './dialog-action-button';
import Image from '../image';
import Space from '../space';

function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }

  if (!value || !value.then) {
    value = Promise.resolve(value);
  }

  return then ? value.then(then) : value;
}

var classPrefix = "am-dialog";

function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }

    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}

var defaultProps = {
  actions: [],
  closeOnAction: false,
  closeOnMaskClick: false
};
export var Dialog = function Dialog(p) {
  var props = mergeProps(defaultProps, p);
  return /*#__PURE__*/React.createElement(Mask, {
    visible: props.visible,
    destroyOnClose: true,
    getContainer: props.getContainer,
    afterClose: props.afterClose,
    onMaskClick: props.closeOnMaskClick ? props.onClose : undefined,
    style: props.maskStyle,
    className: classNames(classPrefix + "-mask", props.maskClassName)
  }, /*#__PURE__*/React.createElement("div", {
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    className: classPrefix + "-wrap"
  }, !!props.image && /*#__PURE__*/React.createElement(Image, {
    src: props.image,
    alt: 'dialog header image',
    width: '100%'
  }), /*#__PURE__*/React.createElement("div", {
    style: props.bodyStyle,
    className: classNames(classPrefix + "-body", props.bodyClassName)
  }, /*#__PURE__*/React.createElement(Space, {
    direction: 'vertical',
    block: true
  }, !!props.header && /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-body-header-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-body-header"
  }, props.header)), !!props.title && /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-body-title"
  }, props.title), !!props.content && /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-body-message-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-body-message"
  }, props.content)))), /*#__PURE__*/React.createElement("div", {
    className: classPrefix + "-footer"
  }, props.actions.map(function (row, index) {
    var actions = Array.isArray(row) ? row : [row];
    return /*#__PURE__*/React.createElement("div", {
      className: classPrefix + "-action-row",
      key: index
    }, actions.map(function (action, index) {
      return /*#__PURE__*/React.createElement(DialogActionButton, {
        key: action.key,
        action: action,
        onAction: _async(function () {
          return _await(props.onAction == null ? void 0 : props.onAction(action, index), function () {
            if (props.closeOnAction) {
              props.onClose == null ? void 0 : props.onClose();
            }
          });
        })
      });
    }));
  }))));
};